@@ -10,4 +10,7 @@ def attr2map_core(*args):
     '=e)[0\x5d\x2c\x64\u0029\x69\x66\x20e else "")')
 
 def unix2yymmdd(unix_time):
-    return time.strftime("%Y-%m-%d", time.localtime(unix_time))if unix_time != 0 else ''
\ No newline at end of file
+    return time.strftime("%Y-%m-%d", time.localtime(unix_time))if unix_time != 0 else ''
+
+def unix2day(unix_time: int):
+    return (unix_time+28800)//86400
\ No newline at end of file
